#line 2 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pycode.cpp"

#line 4 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pycode.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer pycodeYY_create_buffer
#define yy_delete_buffer pycodeYY_delete_buffer
#define yy_flex_debug pycodeYY_flex_debug
#define yy_init_buffer pycodeYY_init_buffer
#define yy_flush_buffer pycodeYY_flush_buffer
#define yy_load_buffer_state pycodeYY_load_buffer_state
#define yy_switch_to_buffer pycodeYY_switch_to_buffer
#define yyin pycodeYYin
#define yyleng pycodeYYleng
#define yylex pycodeYYlex
#define yylineno pycodeYYlineno
#define yyout pycodeYYout
#define yyrestart pycodeYYrestart
#define yytext pycodeYYtext
#define yywrap pycodeYYwrap
#define yyalloc pycodeYYalloc
#define yyrealloc pycodeYYrealloc
#define yyfree pycodeYYfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE pycodeYYrestart(pycodeYYin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t pycodeYYleng;

extern FILE *pycodeYYin, *pycodeYYout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pycodeYYtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up pycodeYYtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via pycodeYYrestart()), so that the user can continue scanning by
	 * just pointing pycodeYYin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when pycodeYYtext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t pycodeYYleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow pycodeYYwrap()'s to do buffer switches
 * instead of setting up a fresh pycodeYYin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void pycodeYYrestart (FILE *input_file  );
void pycodeYY_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE pycodeYY_create_buffer (FILE *file,int size  );
void pycodeYY_delete_buffer (YY_BUFFER_STATE b  );
void pycodeYY_flush_buffer (YY_BUFFER_STATE b  );
void pycodeYYpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void pycodeYYpop_buffer_state (void );

static void pycodeYYensure_buffer_stack (void );
static void pycodeYY_load_buffer_state (void );
static void pycodeYY_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER pycodeYY_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE pycodeYY_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE pycodeYY_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE pycodeYY_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *pycodeYYalloc (yy_size_t  );
void *pycodeYYrealloc (void *,yy_size_t  );
void pycodeYYfree (void *  );

#define yy_new_buffer pycodeYY_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        pycodeYYensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pycodeYY_create_buffer(pycodeYYin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        pycodeYYensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pycodeYY_create_buffer(pycodeYYin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define pycodeYYwrap() 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *pycodeYYin = (FILE *) 0, *pycodeYYout = (FILE *) 0;

typedef int yy_state_type;

extern int pycodeYYlineno;

int pycodeYYlineno = 1;

extern char *pycodeYYtext;
#define yytext_ptr pycodeYYtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up pycodeYYtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	pycodeYYleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 67
#define YY_END_OF_BUFFER 68
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[1033] =
    {   0,
    16418,16418,   59,   59,   68,   66,   67,   65,   66,   67,
       64,   67,   58,   66,   67,   63,   66,   67,   57,   66,
       67,   66,   67,   66,   67,   66,   67,   37,   64,   67,
       22,   36,   66,   67,   22,   36,   66,   67,   22,   36,
       66,   67,   22,   36,   66,   67,   22,   36,   66,   67,
       22,   36,   66,   67,   22,   36,   66,   67,   22,   36,
       66,   67,   22,   36,   66,   67,   22,   36,   66,   67,
       22,   36,   66,   67,   22,   36,   66,   67,   22,   36,
       66,   67,   22,   36,   66,   67,   22,   36,   66,   67,
       22,   36,   66,   67,   22,   36,   66,   67,   22,   36,

       66,   67,   22,   36,   66,   67,   22,   36,   66,   67,
       22,   36,   66,   67,   22,   36,   66,   67,   22,   36,
       66,   67,   22,   36,   66,   67,   65,   66,   67,   13,
       66,   67,   12,   66,   67,   12,   66,   67,   12,   66,
       67,   12,   66,   67,   15,   66,   67,   14,   65,   66,
       67,   15,   58,   66,   67,   15,   63,   66,   67,   15,
       57,   66,   67,   16,   66,   67,   14,   15,   66,   67,
       17,   66,   67,   15,   66,   67,   15,   66,   67,   15,
       66,   67,   15,   66,   67,    8,   66,   67,    8,   66,
       67,    8,   66,   67,    8,   66,   67,    9,   65,   66,

       67,    9,   66,   67,   11,   66,   67,   10,   66,   67,
       10,   66,   67,   10,   66,   67,   10,   66,   67,   35,
       64,   67,   22,   66,   67,   22,   66,   67,   22,   66,
       67,   22,   66,   67,   22,   66,   67,   22,   66,   67,
       22,   66,   67,   22,   66,   67,   22,   66,   67,   22,
       66,   67,   22,   66,   67,   22,   66,   67,   22,   66,
       67,   22,   66,   67,   22,   66,   67,   22,   66,   67,
       22,   66,   67,   22,   66,   67,   22,   66,   67,   22,
       66,   67,   22,   66,   67,   22,   66,   67,   22,   66,
       67,   22,   66,   67,   31,   65,   66,   67,   30,   64,

       67,   23,   65,   66,   67,   29,   64,   67,   63,   66,
       67,   27,   66,   67,   27,   66,   67,   27,   66,   67,
       27,   66,   67,   27,   66,   67,   27,   66,   67,   27,
       66,   67,   27,   66,   67,   27,   66,   67,   27,   66,
       67,   27,   66,   67,   27,   66,   67,   27,   66,   67,
       27,   66,   67,   27,   66,   67,   27,   66,   67,   27,
       66,   67,   27,   66,   67,   27,   66,   67,   27,   66,
       67,   27,   66,   67,   27,   66,   67,   65,   66,   67,
    16416,   33,   64,   67, 8226,   66,   67, 8226,   63,   66,
       67, 8226,   66,   67, 8226,   66,   67, 8226,   66,   67,

       42,   43,   66,   67,   42,   43,   65,   66,   67,   43,
       58,   66,   67,   42,   43,   63,   66,   67,   41,   43,
       57,   66,   67,   42,   43,   66,   67,   42,   43,   66,
       67,   43,   66,   67,   42,   43,   66,   67,   48,   49,
       66,   67,   48,   49,   65,   66,   67,   47,   49,   58,
       66,   67,   48,   49,   63,   66,   67,   49,   57,   66,
       67,   48,   49,   66,   67,   48,   49,   66,   67,   49,
       66,   67,   48,   49,   66,   67,   52,   54,   66,   67,
       52,   54,   65,   66,   67,   52,   53,   64,   67,   52,
       54,   58,   66,   67,   52,   54,   63,   66,   67,   52,

       54,   57,   66,   67,   52,   54,   66,   67,   52,   54,
       66,   67,   54,   66,   67,   52,   54,   66,   67,   59,
       66,   67,   59,   65,   66,   67,   61,   64,   67,   58,
       59,   66,   67,   59,   63,   66,   67,   57,   59,   66,
       67,   59,   66,   67,   59,   66,   67,   59,   66,   67,
       65,   63,   62,   63,   58,   57,   20,   22,   36,   22,
       36,   22,   36,   22,   36,   22,   36,   22,   36,   18,
       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   19,   22,   36,   22,   36,   19,   22,   36,

       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       65,   13,   12,   12,   15,   14,   65,   15,   15,   63,
       15,   62,   63,   15,   15,   15,   58,   15,   57,   15,
        8,    8,    9,   65,   10,   10,   22,   22,   22,   22,
       22,   22,   18,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   19,   22,   22,   19,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   31,
       65,   30,   23,   65,   28,   62,   63,   27,   27,   27,
       27,   27,   25,   27,   27,   27,   27,   27,   27,   27,

       27,   27,   27,   27,   26,   27,   27,   26,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   65,16416,
       33, 8224,   42,   42,   65,   42,   63,   42,   62,   63,
       58,   42,   39,   39,   38,   48,   48,   65,   48,   63,
       48,   62,   63,   57,   48,   45,   45,   44,   52,   52,
       65,   52,   52,   63,   52,   62,   63,   63,   52,   52,
       59,   59,   65,   60,   59,   59,   63,   59,   62,   63,
       59,   58,   59,   57,   59,   59,   56,   55,   21,   22,
       36,   22,   36,   22,   36,   22,   36,   22,   36,   22,
       36,   22,   36,   22,   36,   18,   22,   36,   22,   36,

       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   22,   36,   22,   36,   22,   36,   15,   56,
       15,   55,   10,   22,   22,   22,   22,   22,   22,   22,
       22,   18,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   27,   27,
       27,   27,   27,   27,   25,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       40,   56,   46,   55,   50,   56,   51,   55,   56,   59,
       55,   59,   21,   22,   36,    3,   22,   36,   18,   22,

       36,   22,   36,   22,   36,   22,   36,   22,   36,    1,
       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   22,   36,   22,   36,   22,   36,   22,   36,
       22,   36,   22,    3,   22,   18,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   24,   26,   27,   27,   27,   27,   27,   27,
       22,   36,   18,   22,   36,    7,   21,   22,   36,   22,
       36,   22,   36,   22,   36,   22,   36,   22,   36,   22,
       36,   22,   18,   22,   22,   22,   22,   22,   22,   22,

       22,   27,   27,   27,   27,   27,   27,   27,   27,    2,
        6,   20,    7,   21,   22,   36,   22,   36,    5,   21,
       22,   22,   27,   27,   22,   36,    4,   20,    5,   21,
       22,   27
    } ;

static yyconst flex_int16_t yy_accept[541] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    4,    5,    6,    8,   11,   13,   16,   19,   22,
       24,   26,   28,   31,   35,   39,   43,   47,   51,   55,
       59,   63,   67,   71,   75,   79,   83,   87,   91,   95,
       99,  103,  107,  111,  115,  119,  123,  127,  130,  133,
      136,  139,  142,  145,  148,  152,  156,  160,  164,  167,
      171,  174,  177,  180,  183,  186,  189,  192,  195,  198,
      202,  205,  208,  211,  214,  217,  220,  223,  226,  229,

      232,  235,  238,  241,  244,  247,  250,  253,  256,  259,
      262,  265,  268,  271,  274,  277,  280,  283,  286,  289,
      292,  295,  299,  302,  306,  309,  312,  315,  318,  321,
      324,  327,  330,  333,  336,  339,  342,  345,  348,  351,
      354,  357,  360,  363,  366,  369,  372,  375,  378,  382,
      385,  388,  392,  395,  398,  401,  405,  410,  414,  419,
      424,  428,  432,  435,  439,  443,  448,  453,  458,  462,
      466,  470,  473,  477,  481,  486,  490,  495,  500,  505,
      509,  513,  516,  520,  523,  527,  530,  534,  538,  542,
      545,  548,  551,  552,  552,  553,  555,  555,  556,  557,

      557,  558,  558,  560,  562,  564,  566,  568,  570,  573,
      575,  577,  579,  581,  583,  585,  587,  589,  591,  593,
      596,  598,  601,  603,  605,  607,  609,  611,  613,  615,
      617,  619,  621,  622,  623,  624,  625,  626,  628,  629,
      631,  634,  635,  636,  638,  640,  641,  642,  643,  645,
      645,  646,  647,  648,  649,  650,  651,  652,  653,  655,
      656,  657,  658,  659,  660,  661,  662,  663,  664,  665,
      667,  668,  670,  671,  672,  673,  674,  675,  676,  677,
      678,  679,  680,  682,  683,  685,  688,  689,  690,  691,
      692,  693,  695,  696,  697,  698,  699,  700,  701,  702,

      703,  704,  705,  707,  708,  710,  711,  712,  713,  714,
      715,  716,  717,  718,  719,  721,  722,  723,  724,  726,
      726,  728,  731,  732,  733,  734,  735,  736,  737,  739,
      741,  744,  744,  745,  746,  747,  748,  749,  750,  750,
      752,  753,  755,  758,  759,  760,  761,  762,  764,  764,
      765,  766,  768,  771,  772,  774,  776,  777,  778,  779,
      780,  782,  784,  786,  788,  790,  792,  794,  796,  799,
      801,  803,  805,  807,  809,  811,  813,  815,  817,  819,
      821,  823,  825,  827,  829,  831,  833,  834,  835,  836,
      837,  838,  839,  840,  841,  842,  844,  845,  846,  847,

      848,  849,  850,  851,  852,  853,  854,  855,  856,  857,
      858,  859,  860,  861,  862,  863,  864,  865,  867,  868,
      869,  870,  871,  872,  873,  874,  875,  876,  877,  878,
      879,  880,  881,  883,  883,  885,  885,  887,  889,  891,
      893,  894,  896,  899,  902,  904,  906,  908,  908,  910,
      911,  913,  915,  917,  919,  921,  923,  925,  927,  929,
      931,  933,  934,  936,  938,  939,  940,  941,  942,  943,
      944,  945,  946,  947,  948,  949,  950,  951,  952,  953,
      954,  955,  956,  957,  958,  959,  960,  961,  962,  963,
      966,  967,  968,  969,  970,  971,  973,  976,  978,  980,

      982,  984,  986,  988,  990,  992,  992,  993,  995,  996,
      997,  998,  999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
     1007, 1008, 1009, 1010, 1011, 1013, 1015, 1017, 1019, 1021,
     1022, 1023, 1024, 1025, 1027, 1029, 1031, 1032, 1033, 1033
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    4,    4,    7,    8,
        9,    4,    4,   10,    4,   11,    4,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   13,    4,    4,
        4,    4,    1,    1,   14,   14,   14,   14,   14,   15,
       14,   14,   14,   14,   14,   14,   14,   16,   14,   14,
       14,   17,   14,   18,   19,   14,   14,   14,   14,   14,
        4,   20,    4,    1,   21,    4,   22,   23,   24,   25,

       26,   27,   28,   29,   30,   14,   31,   32,   33,   34,
       35,   36,   14,   37,   38,   39,   40,   14,   41,   42,
       43,   14,    4,    4,    4,    4,    1,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,

       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14
    } ;

static yyconst flex_int32_t yy_meta[44] =
    {   0,
        1,    2,    3,    4,    5,    4,    5,    6,    2,    4,
        7,    8,    2,    9,    9,    9,    9,    9,    9,   10,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9
    } ;

static yyconst flex_int16_t yy_base[574] =
    {   0,
        0,   39,   79,    0,  122,    0,  165,    0,  208,    0,
      251,    0,  294,    0,    6,    8,  337,    0,  380,  420,
        0,    0,    0,    0,  459,  498,  537,  576,  615,  654,
      693,  732, 1724, 1725, 1721, 1725, 1717, 1715, 1713,    7,
       11,   15, 1725,   13,   25,   15,   46,   23,  387,   27,
      382,  380,   51,  398,  399,  400,  420,   56,  433,  405,
      437,  462,  392,  435,  475,  427,   19,   61, 1725,    0,
        8,  470,  504,    0, 1717, 1713,  489, 1710, 1725,    0,
     1725,  772,  792,   38,  434,    0,   61,  509,  515, 1714,
     1725, 1725, 1704,  518,  548,  553, 1725,   62,  441,  502,

      523,  482,  592,  537,  525,  576,  565,  594,  593,  578,
      604,  539,  516,  555,  632,  640,  638,  561,  670,  657,
      633,   69, 1725, 1712, 1725, 1707,    0, 1690,  501, 1674,
      665,    5, 1673,  370, 1683,  582,  653, 1676,  670, 1685,
     1652, 1640,  679,  706, 1622,  710, 1608, 1600,  565, 1725,
     1725, 1622,  620,  719,  724,    0, 1606, 1596,  737, 1592,
      713,  743,  604,  747,    0, 1589, 1567,  761, 1562,  714,
      748,  677,  783, 1548,  394, 1539, 1547,  801, 1542,  804,
      808,  784,  809,    0, 1546,   23, 1528, 1463, 1461,  718,
      825,  826, 1465, 1461,    0,    0, 1458, 1457, 1454,  812,

     1725,    0,  642,  763,  826,  827,  842,  681,  828,  833,
      843,  844,  850,  860,  751,  861,  862,  868,  872,  874,
      876,  878,  880,  885,  889,  893,  898,  894,  900,  906,
      907,  908,  586, 1725,    0,  887,    0, 1457, 1453,  927,
      937, 1449,  915, 1450, 1446,    0,    0,  936, 1450,    0,
     1440,  937,  943,  944,  945,  949,  954,  955,  956,  960,
      961,  962,  966,  967,  974,  973,  979,  980,  984,  992,
      993,  998, 1000, 1002, 1006, 1010, 1012, 1014, 1016, 1020,
     1024, 1026,  682, 1725, 1448,    0,    0, 1417, 1408, 1031,
     1422, 1408, 1414, 1401, 1384, 1385,  451, 1387, 1376, 1367,

     1363, 1361,    0, 1345,    0, 1332, 1325, 1312, 1312, 1297,
     1276, 1252, 1264, 1260,  743, 1725, 1725,    0, 1272, 1260,
     1038, 1042, 1250, 1050, 1725,  820, 1725,    0, 1251, 1054,
     1059, 1240, 1235, 1060, 1725,  854, 1725, 1220, 1065,  656,
     1225, 1066, 1073, 1195, 1182, 1070,    0, 1180,  703, 1725,
     1166,    0,    0, 1162, 1158, 1152, 1076, 1725, 1725, 1074,
     1076, 1080, 1081, 1086, 1087, 1088, 1092, 1093, 1100, 1102,
     1107, 1108, 1109, 1113, 1114, 1119, 1127, 1128, 1133, 1132,
     1134, 1141, 1140, 1145,    0,    0, 1136, 1147, 1149, 1153,
     1154, 1165, 1170, 1175, 1180, 1182, 1184, 1186, 1188, 1193,

     1192, 1194, 1198, 1199, 1205, 1210, 1212, 1216, 1218, 1220,
     1226, 1090, 1097, 1079, 1038, 1018, 1012,    0, 1023, 1020,
     1013, 1008,  993,  989,  967,  935,  909,  904,  893,  890,
      889,  878, 1725,  872, 1725,  923, 1725, 1725,    0,    0,
     1224, 1228, 1230, 1238, 1240, 1249, 1251,    0, 1253,  862,
     1255, 1260, 1259, 1261, 1265, 1267, 1271, 1276, 1277, 1285,
     1291, 1292, 1293, 1297, 1299, 1301, 1306, 1311, 1312, 1313,
     1317, 1318, 1322, 1323, 1327, 1329, 1335, 1341, 1343,  822,
      803,  796,  780,  780,  769,  769,  772,  749,  745,    0,
      724,  732,  703,  696,  689, 1348, 1361, 1349, 1350, 1362,

     1363, 1367, 1368, 1369, 1374,    0, 1375, 1386, 1381, 1382,
     1392, 1394, 1398, 1405, 1409,  654,  633,  600,  601,  587,
      541,  527,  460,  483, 1725, 1411, 1417, 1421, 1422, 1423,
     1427,  415,  407, 1428, 1725, 1433, 1434,  407, 1725, 1470,
     1480, 1490, 1500, 1510, 1520, 1530, 1535, 1537, 1546, 1556,
     1566, 1569, 1572, 1576, 1578, 1586, 1596, 1605, 1615, 1625,
     1634, 1644, 1654, 1664, 1674, 1684,  392,  380, 1689,  375,
     1693,   65, 1697
    } ;

static yyconst flex_int16_t yy_def[574] =
    {   0,
      540,  540,  539,    3,  539,    5,  539,    7,  539,    9,
      539,   11,  539,   13,    2,    2,  539,   17,  541,  541,
        2,    2,    2,    2,  542,  542,  543,  543,  544,  544,
      545,  545,  539,  539,  539,  539,  539,  546,  539,  539,
      539,  539,  539,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  539,  539,  548,
      548,  548,  548,  549,  539,  549,  550,  549,  539,  549,
      539,  551,  551,   83,   83,  552,  552,  552,  552,  539,
      539,  539,  553,  553,  553,  553,  539,  554,  554,  554,

      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  539,  539,  539,  539,  546,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  556,  539,
      539,  546,  539,  539,  539,  557,  557,  539,  558,  539,
      557,  557,  559,  557,  560,  560,  539,  561,  539,  560,
      560,  562,  560,  563,  563,  563,  539,  564,  539,  563,
      563,  563,  563,  565,  565,  539,  565,  566,  565,  565,
      565,  565,  539,  539,  546,  546,  539,  539,  539,  539,

      539,  567,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  539,  539,  548,  548,  549,  539,  549,  550,
      550,  549,   83,  549,  549,   83,  552,  552,  539,  568,
      553,  553,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  539,  539,  539,  546,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,

      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  556,  539,  539,  557,  557,  539,
      558,  558,  539,  557,  539,  539,  539,  560,  560,  561,
      561,  539,  539,  560,  539,  539,  539,  563,  563,  563,
      539,  564,  564,  564,  539,  563,  565,  565,  539,  539,
      565,  566,  566,  565,  565,  565,  565,  539,  539,  569,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  549,  549,  553,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,

      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  539,  539,  539,  539,  539,  539,  565,  565,
      569,  547,  547,  547,  547,  547,  547,  570,  547,  539,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  547,  547,  571,  547,  547,

      547,  547,  547,  547,  547,  572,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  555,  555,  555,  555,  555,
      555,  555,  555,  539,  539,  571,  547,  547,  573,  554,
      554,  555,  555,  547,  539,  573,  554,  555,    0,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539
    } ;

static yyconst flex_int16_t yy_nxt[1769] =
    {   0,
      539,   35,   36,  539,   37,   38,   39,  122,  123,  122,
      123,  198,  198,  199,  199,  198,   40,  199,   41,  198,
      201,  199,  201,  202,  349,  202,  201,  200,  350,  202,
      201,  200,  201,  202,  201,  202,   40,  202,  291,   42,
       35,   36,  292,   37,   38,   39,  204,  200,  232,  205,
      198,  200,  199,  201,  246,   40,  202,   41,  201,  206,
      208,  202,  233,  201,  209,  198,  202,  199,  234,  201,
      283,  284,  202,  529,  246,   40,  213,  223,   42,   34,
       35,   43,   34,   37,   38,   39,   34,   34,   34,   34,
       34,   34,   44,   45,   46,   47,   48,   49,   34,   44,

       50,   51,   52,   53,   54,   55,   56,   44,   57,   44,
       58,   44,   59,   60,   61,   62,   63,   64,   65,   66,
       44,   67,   34,   68,   36,   34,   37,   38,   39,   69,
       34,   34,   34,   34,   34,   70,   70,   70,   71,   70,
       72,   34,   70,   70,   70,   70,   70,   70,   70,   70,
       70,   70,   70,   70,   70,   70,   70,   70,   71,   70,
       70,   73,   70,   70,   70,   74,   75,   36,   74,   76,
       77,   78,   34,   79,   80,   74,   74,   81,   82,   82,
       82,   83,   82,   84,   74,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,

       82,   83,   82,   82,   85,   82,   82,   82,   34,   35,
       36,   34,   37,   38,   39,   34,   34,   34,   34,   34,
       34,   86,   86,   86,   87,   86,   88,   34,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   87,   86,   86,   89,   86,   86,
       86,   34,   90,   36,   34,   37,   38,   39,   91,   91,
       91,   34,   34,   92,   93,   93,   93,   94,   93,   95,
       34,   93,   93,   93,   93,   93,   93,   93,   93,   93,
       93,   93,   93,   93,   93,   93,   93,   94,   93,   93,
       96,   93,   93,   93,   34,   35,   97,   34,   37,   38,

       39,   34,   34,   34,   34,   34,   34,   98,   99,  100,
      101,  102,  103,   34,   98,  104,  105,  106,  107,  108,
      109,  110,   98,  111,   98,  112,   98,  113,  114,  115,
      116,  117,  118,  119,  120,   98,  121,   34,  124,  125,
       34,   37,  126,   39,   34,   34,   34,   34,   34,   34,
      127,  128,  127,  129,  130,  131,   34,  127,  132,  133,
      134,  135,  136,  137,  138,  127,  139,  127,  140,  127,
      141,  142,  143,  144,  127,  145,  146,  147,  127,  148,
       34,  149,  150,  498,   37,  152,   39,  201,  387,  201,
      202,  198,  202,  199,  201,  340,  153,  202,  154,  201,

      360,  294,  202,  207,  295,  201,  201,  201,  202,  202,
      202,  211,  201,  339,  212,  202,  153,  229,  210,  155,
       34,  149,  150,  207,   37,  152,   39,  201,  216,  214,
      202,  219,  305,  217,  201,  218,  153,  202,  154,  215,
      201,  222,  201,  202,  201,  202,  220,  202,  201,  305,
      246,  202,  221,  222,  538,  231,  153,  222,  225,  155,
      157,   36,  254,  158,  159,  160,  198,  224,  199,  201,
      246,  230,  202,  226,  198,  161,  199,  162,  163,  198,
      419,  199,  201,  227,  524,  202,  236,  228,  420,  201,
      195,  207,  202,  305,  241,  161,  195,  195,  164,  157,

       36,  195,  158,  159,  160,  198,  236,  199,  198,  201,
      199,  207,  202,  198,  161,  199,  162,  163,  256,  198,
      236,  199,  198,  201,  199,  248,  202,  198,  250,  199,
      201,  248,  201,  202,  161,  202,  255,  164,  166,   36,
      236,  167,  168,  169,  201,  248,  201,  202,  418,  202,
      274,  248,  198,  170,  199,  171,  172,  198,  250,  199,
      273,  260,  201,  250,  252,  202,  315,  316,  201,  252,
      258,  202,  201,  170,  259,  202,  173,  166,   36,  418,
      167,  168,  169,  201,  252,  201,  202,  233,  202,  252,
      263,  272,  170,  234,  171,  172,  198,  280,  199,  201,

      201,  201,  202,  202,  202,  326,  327,  261,  257,  269,
      262,  201,  170,  297,  202,  173,  175,  176,  418,  177,
      178,  179,  266,  298,  198,  264,  199,  267,  257,  268,
      270,  180,  533,  181,  182,  265,  271,  272,  305,  201,
      201,  272,  202,  202,  198,  201,  199,  201,  202,  201,
      202,  180,  202,  275,  183,  175,  176,  340,  177,  178,
      179,  277,  282,  279,  201,  278,  532,  202,  276,  198,
      180,  199,  181,  182,  198,  339,  199,  201,  336,  337,
      202,  290,  299,  283,  284,  281,  257,  300,  201,  301,
      180,  202,  418,  183,  185,  186,  303,  187,  188,  189,

      308,  290,  304,  305,  349,  222,  257,  305,  350,  190,
      198,  191,  199,  305,  198,  309,  199,  323,  198,  199,
      333,  305,  355,  198,  356,  199,  290,  310,  198,  190,
      199,  311,  192,  185,  186,  200,  187,  188,  189,  523,
      200,  195,  322,  195,  315,  316,  290,  323,  190,  199,
      191,  323,  198,  199,  333,  200,  195,  305,  201,  324,
      200,  202,  305,  324,  334,  195,  331,  195,  190,  522,
      201,  192,  237,  202,  372,  237,  237,  237,  237,  324,
      195,  237,  237,  324,  334,  521,  539,  198,  338,  333,
      338,  237,  237,  520,  361,  237,  244,  237,  245,  334,

      519,  237,  237,  338,  518,  195,  343,  195,  198,  517,
      199,  237,  198,  198,  199,  199,  198,  418,  199,  334,
      344,  434,  327,  339,  346,  346,  305,  339,  339,  355,
      355,  356,  356,  201,  201,  201,  202,  202,  202,  516,
      201,  357,  357,  202,  346,  346,  198,  418,  199,  201,
      201,  201,  202,  202,  202,  436,  337,  201,  365,  362,
      202,  357,  357,  450,  366,  364,  363,  201,  201,  201,
      202,  202,  202,  434,  327,  201,  369,  368,  202,  201,
      367,  201,  202,  201,  202,  201,  202,  201,  202,  370,
      202,  198,  201,  199,  373,  202,  201,  371,  222,  202,

      201,  201,  374,  202,  202,  201,  375,  201,  202,  495,
      202,  376,  377,  201,  201,  201,  202,  202,  202,  237,
      494,  237,  379,  222,  436,  337,  378,  380,  195,  493,
      492,  382,  381,  384,  195,  195,  383,  491,  195,  195,
      198,  198,  199,  199,  195,  195,  490,  250,  222,  195,
      201,  201,  201,  202,  202,  202,  201,  489,  198,  202,
      199,  201,  201,  201,  202,  202,  202,  201,  201,  201,
      202,  202,  202,  201,  201,  388,  202,  202,  389,  272,
      201,  201,  393,  202,  202,  392,  201,  201,  390,  202,
      202,  201,  396,  391,  202,  395,  397,  399,  394,  201,

      201,  488,  202,  202,  398,  201,  400,  201,  202,  201,
      202,  487,  202,  201,  401,  272,  202,  201,  402,  201,
      202,  201,  202,  201,  202,  418,  202,  201,  403,  486,
      202,  201,  404,  201,  202,  198,  202,  199,  485,  406,
      272,  407,  195,  405,  195,  305,  195,  409,  195,  305,
      484,  411,  408,  410,  323,  483,  199,  195,  195,  482,
      195,  195,  272,  195,  198,  195,  333,  539,  338,  338,
      195,  338,  195,  195,  198,  338,  199,  195,  195,  195,
      355,  201,  356,  201,  202,  344,  202,  201,  201,  339,
      202,  202,  344,  201,  201,  201,  202,  202,  202,  201,

      201,  450,  448,  202,  481,  443,  444,  201,  446,  201,
      202,  445,  202,  442,  201,  201,  201,  202,  202,  202,
      201,  201,  418,  202,  202,  447,  201,  480,  222,  202,
      452,  449,  222,  451,  201,  201,  453,  202,  202,  201,
      201,  201,  202,  202,  202,  444,  250,  201,  201,  455,
      202,  202,  201,  454,  201,  202,  201,  202,  354,  202,
      201,  201,  351,  202,  202,  222,  456,  459,  440,  457,
      439,  460,  201,  458,  463,  202,  461,  201,  464,  465,
      202,  348,  201,  450,  462,  448,  466,  201,  438,  201,
      202,  201,  202,  201,  202,  201,  202,  539,  202,  201,

      201,  201,  202,  202,  202,  201,  201,  467,  202,  202,
      272,  272,  201,  469,  470,  202,  471,  201,  468,  201,
      202,  473,  202,  201,  464,  201,  202,  201,  202,  437,
      202,  201,  472,  201,  202,  201,  202,  201,  202,  339,
      202,  332,  272,  474,  477,  201,  435,  201,  202,  475,
      202,  478,  329,  444,  320,  476,  201,  479,  201,  202,
      201,  202,  201,  202,  433,  202,  201,  201,  201,  202,
      202,  202,  201,  319,  201,  202,  496,  202,  201,  222,
      502,  202,  499,  201,  201,  432,  202,  506,  497,  504,
      500,  501,  201,  431,  305,  202,  222,  503,  201,  201,

      201,  202,  202,  202,  201,  222,  201,  202,  201,  202,
      222,  202,  505,  201,  430,  222,  202,  464,  201,  201,
      201,  202,  202,  202,  201,  201,  429,  202,  202,  201,
      201,  272,  202,  202,  201,  507,  201,  202,  512,  202,
      509,  428,  201,  508,  511,  506,  514,  510,  201,  427,
      201,  202,  272,  202,  513,  201,  525,  201,  202,  202,
      202,  272,  524,  305,  426,  515,  272,  272,  201,  201,
      201,  202,  202,  202,  201,  201,  201,  202,  202,  202,
      425,  201,  201,  527,  202,  202,  444,  524,  201,  201,
      444,  202,  202,  201,  528,  424,  202,  423,  444,  201,

      222,  201,  202,  305,  202,  201,  444,  222,  202,  422,
      421,  418,  201,  464,  530,  202,  201,  417,  525,  202,
      272,  202,  416,  531,  201,  464,  464,  202,  201,  535,
      201,  202,  202,  202,  201,  201,  464,  202,  202,  415,
      535,  201,  272,  202,  202,  414,  305,  413,  412,  285,
      250,  249,  242,  222,  239,  386,  534,  385,  238,  272,
      197,  194,  537,  222,  359,  358,  193,  354,  353,  272,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      156,  156,  156,  156,  156,  156,  156,  156,  156,  156,

      165,  165,  165,  165,  165,  165,  165,  165,  165,  165,
      174,  174,  174,  174,  174,  174,  174,  174,  174,  174,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      195,  195,  351,  195,  195,  195,  195,  195,  195,  195,
      203,  203,  203,  203,  235,  235,  237,  348,  345,  237,
      237,  341,  237,  237,  237,  237,  240,  240,  339,  240,
      240,  240,  240,  240,  240,  240,  243,  339,  332,  243,
      243,  194,  243,  243,  243,  243,  247,  247,  251,  251,
      251,  253,  253,  253,  253,  287,  287,  317,  317,  317,
      329,  317,  317,  317,  317,  317,  318,  318,  197,  318,

      320,  318,  318,  318,  318,  321,  321,  319,  321,  321,
      321,  321,  321,  321,  321,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  328,  328,  196,  328,  314,
      328,  328,  328,  328,  330,  330,  313,  330,  330,  330,
      330,  330,  330,  330,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  338,  338,  338,  338,  312,  338,
      338,  338,  338,  338,  342,  342,  342,  342,  342,  342,
      342,  342,  342,  342,  347,  347,  305,  347,  347,  347,
      347,  347,  347,  347,  352,  352,  307,  352,  352,  352,
      352,  352,  352,  352,  441,  441,  441,  441,  526,  526,

      526,  526,  536,  536,  536,  536,  306,  302,  296,  293,
      289,  288,  286,  285,  250,  249,  242,  239,  238,  197,
      196,  194,  193,  539,   33,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539
    } ;

static yyconst flex_int16_t yy_chk[1769] =
    {   0,
        0,    1,    1,    0,    1,    1,    1,   15,   15,   16,
       16,   40,   71,   40,   71,   41,    1,   41,    1,   42,
       44,   42,   46,   44,  186,   46,   67,   41,  186,   67,
       48,   42,   45,   48,   50,   45,    1,   50,  132,    1,
        2,    2,  132,    2,    2,    2,   45,   41,   67,   46,
       47,   42,   47,   47,   84,    2,   47,    2,   53,   48,
       50,   53,   68,   58,   50,   87,   58,   87,   68,   98,
      122,  122,   98,  572,   84,    2,   53,   58,    2,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   13,   13,   13,   13,   13,   13,

       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       19,   19,   19,  570,   19,   19,   19,   52,  568,   51,
       52,   49,   51,   49,   49,  175,   19,   49,   19,   63,

      567,  134,   63,   49,  134,   54,   55,   56,   54,   55,
       56,   52,   60,  175,   52,   60,   19,   63,   51,   19,
       20,   20,   20,   49,   20,   20,   20,   57,   55,   54,
       57,   56,  538,   55,   66,   55,   20,   66,   20,   54,
       59,   60,   64,   59,   61,   64,   57,   61,   99,  533,
       85,   99,   57,   57,  532,   66,   20,   57,   61,   20,
       25,   25,   99,   25,   25,   25,   62,   59,   62,   62,
       85,   64,   62,   61,   72,   25,   72,   25,   25,   65,
      297,   65,   65,   62,  524,   65,   72,   62,  297,  102,
       77,   65,  102,  523,   77,   25,   77,   77,   25,   26,

       26,   77,   26,   26,   26,  129,   72,  129,   73,  100,
       73,   65,  100,   88,   26,   88,   26,   26,  102,   89,
       73,   89,   94,  113,   94,   88,  113,  101,   94,  101,
      101,   89,  105,  101,   26,  105,  100,   26,   27,   27,
       73,   27,   27,   27,  104,   88,  112,  104,  522,  112,
      113,   89,   95,   27,   95,   27,   27,   96,   95,   96,
      112,  105,  114,   96,   95,  114,  149,  149,  118,   96,
      104,  118,  107,   27,  104,  107,   27,   28,   28,  521,
       28,   28,   28,  106,   95,  110,  106,  233,  110,   96,
      107,  114,   28,  233,   28,   28,  103,  118,  103,  103,

      109,  108,  103,  109,  108,  163,  163,  106,  103,  110,
      106,  111,   28,  136,  111,   28,   29,   29,  520,   29,
       29,   29,  109,  136,  153,  108,  153,  109,  103,  109,
      111,   29,  519,   29,   29,  108,  111,  111,  518,  115,
      121,  111,  115,  121,  116,  117,  116,  116,  117,  203,
      116,   29,  203,  115,   29,   30,   30,  340,   30,   30,
       30,  116,  121,  117,  120,  116,  517,  120,  115,  131,
       30,  131,   30,   30,  119,  340,  119,  119,  172,  172,
      119,  131,  137,  283,  283,  120,  119,  137,  208,  137,
       30,  208,  516,   30,   31,   31,  139,   31,   31,   31,

      143,  131,  139,  139,  349,  208,  119,  139,  349,   31,
      144,   31,  144,  495,  146,  143,  146,  161,  170,  161,
      170,  494,  190,  154,  190,  154,  146,  144,  155,   31,
      155,  144,   31,   32,   32,  154,   32,   32,   32,  493,
      155,  159,  159,  159,  315,  315,  146,  162,   32,  162,
       32,  164,  171,  164,  171,  154,  159,  492,  215,  162,
      155,  215,  491,  164,  171,  168,  168,  168,   32,  489,
      204,   32,   82,  204,  215,   82,   82,   82,   82,  162,
      168,   82,   82,  164,  171,  488,  182,  173,  182,  173,
      182,   82,   83,  487,  204,   83,   83,   83,   83,  173,

      486,   83,   83,  178,  485,  178,  178,  178,  180,  484,
      180,   83,  181,  183,  181,  183,  200,  483,  200,  173,
      178,  326,  326,  180,  181,  183,  482,  181,  183,  191,
      192,  191,  192,  205,  206,  209,  205,  206,  209,  481,
      210,  191,  192,  210,  181,  183,  207,  480,  207,  207,
      211,  212,  207,  211,  212,  336,  336,  213,  210,  205,
      213,  191,  192,  450,  211,  209,  206,  214,  216,  217,
      214,  216,  217,  434,  434,  218,  213,  212,  218,  219,
      211,  220,  219,  221,  220,  222,  221,  223,  222,  214,
      223,  236,  224,  236,  216,  224,  225,  214,  217,  225,

      226,  228,  218,  226,  228,  227,  219,  229,  227,  432,
      229,  221,  223,  230,  231,  232,  230,  231,  232,  243,
      431,  243,  226,  224,  436,  436,  225,  227,  240,  430,
      429,  229,  228,  232,  240,  240,  231,  428,  241,  240,
      248,  252,  248,  252,  241,  241,  427,  252,  230,  241,
      253,  254,  255,  253,  254,  255,  256,  426,  257,  256,
      257,  257,  258,  259,  257,  258,  259,  260,  261,  262,
      260,  261,  262,  263,  264,  254,  263,  264,  255,  258,
      266,  265,  261,  266,  265,  260,  267,  268,  256,  267,
      268,  269,  263,  259,  269,  262,  264,  265,  261,  270,

      271,  425,  270,  271,  264,  272,  266,  273,  272,  274,
      273,  424,  274,  275,  268,  267,  275,  276,  269,  277,
      276,  278,  277,  279,  278,  423,  279,  280,  271,  422,
      280,  281,  273,  282,  281,  290,  282,  290,  421,  276,
      274,  277,  321,  275,  321,  420,  322,  279,  322,  419,
      417,  282,  278,  281,  324,  416,  324,  321,  330,  415,
      330,  322,  280,  331,  334,  331,  334,  339,  342,  339,
      342,  339,  342,  330,  346,  343,  346,  343,  331,  343,
      357,  360,  357,  361,  360,  342,  361,  362,  363,  346,
      362,  363,  343,  364,  365,  366,  364,  365,  366,  367,

      368,  369,  367,  368,  414,  362,  363,  369,  365,  370,
      369,  364,  370,  361,  371,  372,  373,  371,  372,  373,
      374,  375,  413,  374,  375,  366,  376,  412,  370,  376,
      373,  368,  371,  372,  377,  378,  375,  377,  378,  380,
      379,  381,  380,  379,  381,  374,  387,  383,  382,  377,
      383,  382,  384,  376,  388,  384,  389,  388,  356,  389,
      390,  391,  355,  390,  391,  378,  379,  382,  354,  380,
      351,  383,  392,  381,  389,  392,  384,  393,  390,  391,
      393,  348,  394,  396,  388,  394,  392,  395,  345,  396,
      395,  397,  396,  398,  397,  399,  398,  344,  399,  401,

      400,  402,  401,  400,  402,  403,  404,  393,  403,  404,
      397,  398,  405,  399,  400,  405,  402,  406,  395,  407,
      406,  404,  407,  408,  401,  409,  408,  410,  409,  341,
      410,  441,  403,  411,  441,  442,  411,  443,  442,  338,
      443,  333,  405,  406,  409,  444,  332,  445,  444,  407,
      445,  410,  329,  442,  323,  408,  446,  411,  447,  446,
      449,  447,  451,  449,  320,  451,  453,  452,  454,  453,
      452,  454,  455,  319,  456,  455,  445,  456,  457,  446,
      453,  457,  449,  458,  459,  314,  458,  459,  447,  455,
      451,  452,  460,  313,  312,  460,  457,  454,  461,  462,

      463,  461,  462,  463,  464,  456,  465,  464,  466,  465,
      460,  466,  458,  467,  311,  461,  467,  462,  468,  469,
      470,  468,  469,  470,  471,  472,  310,  471,  472,  473,
      474,  466,  473,  474,  475,  465,  476,  475,  471,  476,
      468,  309,  477,  467,  470,  477,  473,  469,  478,  308,
      479,  478,  475,  479,  472,  496,  498,  499,  496,  498,
      499,  474,  497,  307,  306,  476,  478,  479,  497,  500,
      501,  497,  500,  501,  502,  503,  504,  502,  503,  504,
      304,  505,  507,  499,  505,  507,  496,  508,  509,  510,
      504,  509,  510,  508,  501,  302,  508,  301,  502,  511,

      500,  512,  511,  300,  512,  513,  503,  505,  513,  299,
      298,  296,  514,  507,  509,  514,  515,  295,  526,  515,
      510,  526,  294,  511,  527,  512,  514,  527,  528,  529,
      530,  528,  529,  530,  531,  534,  513,  531,  534,  293,
      536,  537,  515,  536,  537,  292,  291,  289,  288,  285,
      251,  249,  245,  534,  244,  242,  527,  239,  238,  537,
      199,  198,  530,  528,  197,  194,  193,  189,  188,  531,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      542,  542,  542,  542,  542,  542,  542,  542,  542,  542,

      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      544,  544,  544,  544,  544,  544,  544,  544,  544,  544,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      546,  546,  187,  546,  546,  546,  546,  546,  546,  546,
      547,  547,  547,  547,  548,  548,  549,  185,  179,  549,
      549,  177,  549,  549,  549,  549,  550,  550,  176,  550,
      550,  550,  550,  550,  550,  550,  551,  174,  169,  551,
      551,  167,  551,  551,  551,  551,  552,  552,  553,  553,
      553,  554,  554,  554,  554,  555,  555,  556,  556,  556,
      166,  556,  556,  556,  556,  556,  557,  557,  160,  557,

      158,  557,  557,  557,  557,  558,  558,  157,  558,  558,
      558,  558,  558,  558,  558,  559,  559,  559,  559,  559,
      559,  559,  559,  559,  559,  560,  560,  152,  560,  148,
      560,  560,  560,  560,  561,  561,  147,  561,  561,  561,
      561,  561,  561,  561,  562,  562,  562,  562,  562,  562,
      562,  562,  562,  562,  563,  563,  563,  563,  145,  563,
      563,  563,  563,  563,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  565,  565,  142,  565,  565,  565,
      565,  565,  565,  565,  566,  566,  141,  566,  566,  566,
      566,  566,  566,  566,  569,  569,  569,  569,  571,  571,

      571,  571,  573,  573,  573,  573,  140,  138,  135,  133,
      130,  128,  126,  124,   93,   90,   78,   76,   75,   39,
       38,   37,   35,   33,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539
    } ;

extern int pycodeYY_flex_debug;
int pycodeYY_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up pycodeYYtext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *pycodeYYtext;
#line 1 "pycode.l"
/******************************************************************************
 *
 * 
 *
 * Copyright (C) 1997-2015 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby 
 * granted. No representations are made about the suitability of this software 
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */
/*  This code is based on the work done by the MoxyPyDoxy team
 *  (Linda Leong, Mike Rivera, Kim Truong, and Gabriel Estrada)
 *  in Spring 2005 as part of CS 179E: Compiler Design Project
 *  at the University of California, Riverside; the course was
 *  taught by Peter H. Froehlich <phf@acm.org>.
 */
#line 26 "pycode.l"

#include <stdio.h>
#include <qvaluestack.h>

#include "pycode.h"
#include "message.h"

#include "scanner.h"
#include "entry.h"
#include "doxygen.h"
#include "outputlist.h"
#include "util.h"
#include "membername.h"
#include "searchindex.h"
#include "config.h"
#include "groupdef.h"
#include "classlist.h"
#include "filedef.h"
#include "namespacedef.h"
#include "tooltip.h"

// Toggle for some debugging info
//#define DBG_CTX(x) fprintf x
#define DBG_CTX(x) do { } while(0)

#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1

static ClassSDict    g_codeClassSDict(17);
static QCString      g_curClassName;
static QStrList      g_curClassBases;


static CodeOutputInterface * g_code;
static const char *  g_inputString;     //!< the code fragment as text
static int	     g_inputPosition;   //!< read offset during parsing 
static const char *  g_currentFontClass;
static bool          g_needsTermination;
static Definition   *g_searchCtx;
static bool          g_collectXRefs;
static int           g_inputLines;      //!< number of line in the code fragment
static int	     g_yyLineNr;        //!< current line number
static FileDef *     g_sourceFileDef;
static Definition *  g_currentDefinition;
static MemberDef *   g_currentMemberDef;
static bool          g_includeCodeFragment;
static QCString      g_realScope;
//static bool          g_insideBody;
static int           g_bodyCurlyCount;
static bool          g_searchingForBody;
static QCString      g_classScope;
static int           g_paramParens;
//static int           g_anchorCount;

static bool          g_exampleBlock;
static QCString      g_exampleName;

static QCString      g_type;
static QCString      g_name;

static bool          g_doubleStringIsDoc;
static bool          g_doubleQuote;
static bool          g_noSuiteFound;
static int           g_stringContext;

static QValueStack<uint> g_indents;  //!< Tracks indentation levels for scoping in python

static QCString      g_docBlock;     //!< contents of all lines of a documentation block
static bool          g_endComment;

static void endFontClass();
static void adjustScopesAndSuites(unsigned indentLength);


/*! Represents a stack of variable to class mappings as found in the
 *  code. Each scope is enclosed in pushScope() and popScope() calls.
 *  Variables are added by calling addVariables() and one can search
 *  for variable using findVariable().
 */
class PyVariableContext 
{
  public:
    static const ClassDef *dummyContext;    
    class Scope : public SDict<ClassDef> 
    {
      public:
	Scope() : SDict<ClassDef>(17) {}
    };
    
    PyVariableContext() 
    {
      m_scopes.setAutoDelete(TRUE);
    }

    virtual ~PyVariableContext() 
    {
    }
    
    void pushScope() 
    {
      m_scopes.append(new Scope);
    }

    void popScope() 
    {
      if (m_scopes.count()>0) 
      {
	m_scopes.remove(m_scopes.count()-1);
      }
    }

    void clear() 
    {
      m_scopes.clear();
      m_globalScope.clear();
    }

    void clearExceptGlobal() 
    {
      m_scopes.clear();
    }

    void addVariable(const QCString &type,const QCString &name);
    ClassDef *findVariable(const QCString &name);
    
  private:
    Scope        m_globalScope;
    QList<Scope> m_scopes;
};

void PyVariableContext::addVariable(const QCString &type,const QCString &name)
{
  //printf("PyVariableContext::addVariable(%s,%s)\n",type.data(),name.data());
  QCString ltype = type.simplifyWhiteSpace();
  QCString lname = name.simplifyWhiteSpace();

  Scope *scope = m_scopes.count()==0 ? &m_globalScope : m_scopes.getLast();
  ClassDef *varType;
  if (
      (varType=g_codeClassSDict[ltype]) ||  // look for class definitions inside the code block
      (varType=getResolvedClass(g_currentDefinition,g_sourceFileDef,ltype)) // look for global class definitions
     ) 
  {
    scope->append(lname,varType); // add it to a list
  }
  else 
  {
    if (m_scopes.count()>0) // for local variables add a dummy entry so the name 
                            // is hidden to avoid FALSE links to global variables with the same name
                            // TODO: make this work for namespaces as well!
    {
      scope->append(lname,dummyContext);
    }
  }
}

ClassDef *PyVariableContext::findVariable(const QCString &name)
{
  if (name.isEmpty()) return 0;
  ClassDef *result = 0;
  QListIterator<Scope> sli(m_scopes);
  Scope *scope;
  // search from inner to outer scope
  for (sli.toLast();(scope=sli.current());--sli)
  {
    result = scope->find(name);
    if (result) 
    {
      return result;
    }
  }
  // nothing found -> also try the global scope
  result=m_globalScope.find(name);
  return result;
}

static PyVariableContext g_theVarContext;
const ClassDef *PyVariableContext::dummyContext = (ClassDef*)0x8;

class PyCallContext
{
  public:
    struct Ctx
    {
      Ctx() : name(g_name), type(g_type), cd(0) {}
      QCString name;
      QCString type;
      ClassDef *cd;
    };

    PyCallContext() 
    {
      m_classList.append(new Ctx);
      m_classList.setAutoDelete(TRUE);
    }

    virtual ~PyCallContext() {}

    void setClass(ClassDef *cd)
    {
      Ctx *ctx = m_classList.getLast();
      if (ctx) 
      {
        ctx->cd=cd;
      }
    }
    void pushScope()
    {
      m_classList.append(new Ctx);
    }

    void popScope()
    {
      if (m_classList.count()>1)
      {
	Ctx *ctx = m_classList.getLast();
	if (ctx)
	{
	  g_name = ctx->name;
	  g_type = ctx->type;
	}
	m_classList.removeLast();
      }
      else
      {
      }
    }

    void clear()
    {
      m_classList.clear();
      m_classList.append(new Ctx);
    }

    ClassDef *getClass() const
    {
      Ctx *ctx = m_classList.getLast();

      if (ctx)
        return ctx->cd;
      else
        return 0;
    }

  private:
    QList<Ctx> m_classList;    
};

static PyCallContext g_theCallContext;


/*! counts the number of lines in the input */
static int countLines()
{
  const char *p=g_inputString;
  char c;
  int count=1;
  while ((c=*p)) 
  { 
    p++ ; 
    if (c=='\n') count++;  
  }
  if (p>g_inputString && *(p-1)!='\n') 
  { // last line does not end with a \n, so we add an extra
    // line and explicitly terminate the line after parsing.
    count++, 
    g_needsTermination=TRUE; 
  } 
  return count;
}

static void setCurrentDoc(const QCString &anchor)
{
  if (Doxygen::searchIndex)
  {
    if (g_searchCtx)
    {
      Doxygen::searchIndex->setCurrentDoc(g_searchCtx,g_searchCtx->anchor(),FALSE);
    }
    else
    {
      Doxygen::searchIndex->setCurrentDoc(g_sourceFileDef,anchor,TRUE);
    }
  }
}

static void addToSearchIndex(const char *text)
{
  if (Doxygen::searchIndex)
  {
    Doxygen::searchIndex->addWord(text,FALSE);
  }
}


static ClassDef *stripClassName(const char *s,Definition *d=g_currentDefinition)
{
  int pos=0;
  QCString type = s;
  QCString className;
  QCString templSpec;
  while (extractClassNameFromType(type,pos,className,templSpec)!=-1)
  {
    QCString clName=className+templSpec;

    ClassDef *cd=0;
    if (!g_classScope.isEmpty())
    {
      cd=getResolvedClass(d,g_sourceFileDef,g_classScope+"::"+clName);
    }
    if (cd==0)
    {
      cd=getResolvedClass(d,g_sourceFileDef,clName);
    }
    if (cd)
    {
      return cd;
    }
  }

  return 0;
}



/*! start a new line of code, inserting a line number if g_sourceFileDef
 * is TRUE. If a definition starts at the current line, then the line
 * number is linked to the documentation of that definition.
 */
static void startCodeLine()
{
  //if (g_currentFontClass) { g_code->endFontClass(); }
  if (g_sourceFileDef)
  {
    //QCString lineNumber,lineAnchor;
    //lineNumber.sprintf("%05d",g_yyLineNr);
    //lineAnchor.sprintf("l%05d",g_yyLineNr);
   
    Definition *d   = g_sourceFileDef->getSourceDefinition(g_yyLineNr);
    //printf("startCodeLine %d d=%p\n",g_yyLineNr,d);
    //g_code->startLineNumber();

    if (!g_includeCodeFragment && d && d->isLinkableInProject())
    {
      g_currentDefinition = d;
      g_currentMemberDef = g_sourceFileDef->getSourceMember(g_yyLineNr);
      //g_insideBody = FALSE;
      g_endComment = FALSE;
      g_searchingForBody = TRUE;
      g_realScope = d->name().copy();
      g_classScope = d->name().copy();
      //printf("Real scope: `%s'\n",g_realScope.data());
      g_bodyCurlyCount = 0;
      QCString lineAnchor;
      lineAnchor.sprintf("l%05d",g_yyLineNr);
      if (g_currentMemberDef)
      {
        g_code->writeLineNumber(g_currentMemberDef->getReference(),
	                        g_currentMemberDef->getOutputFileBase(),
	                        g_currentMemberDef->anchor(),g_yyLineNr);
        setCurrentDoc(lineAnchor);
      }
      else
      {
        g_code->writeLineNumber(d->getReference(),
	                        d->getOutputFileBase(),
	                        0,g_yyLineNr);
        setCurrentDoc(lineAnchor);
      }
    }
    else
    {
      //g_code->codify(lineNumber);
      g_code->writeLineNumber(0,0,0,g_yyLineNr);
    }
    //g_code->endLineNumber();
  }
  g_code->startCodeLine(g_sourceFileDef); 
  if (g_currentFontClass)
  {
    g_code->startFontClass(g_currentFontClass);
  }
}

static void codify(const char* text) 
{ 
  g_code->codify(text);
}

static void endCodeLine()
{
  endFontClass();
  g_code->endCodeLine();
}

static void nextCodeLine()
{
  const char *fc = g_currentFontClass;
  endCodeLine();
  if (g_yyLineNr<g_inputLines) 
  {
    g_currentFontClass = fc;
    startCodeLine();
  }
}


/*! writes a link to a fragment \a text that may span multiple lines, inserting
 * line numbers for each line. If \a text contains newlines, the link will be 
 * split into multiple links with the same destination, one for each line.
 */
static void writeMultiLineCodeLink(CodeOutputInterface &ol,
                  Definition *d,
                  const char *text)
{
  static bool sourceTooltips = Config_getBool("SOURCE_TOOLTIPS");
  TooltipManager::instance()->addTooltip(d);
  QCString ref  = d->getReference();
  QCString file = d->getOutputFileBase();
  QCString anchor = d->anchor();
  QCString tooltip; 
  if (!sourceTooltips) // fall back to simple "title" tooltips
  {
    tooltip = d->briefDescriptionAsTooltip();
  }
  bool done=FALSE;
  char *p=(char *)text;
  while (!done)
  {
    char *sp=p;
    char c;
    while ((c=*p++) && c!='\n') { }
    if (c=='\n')
    {
      g_yyLineNr++;
      *(p-1)='\0';
      //printf("writeCodeLink(%s,%s,%s,%s)\n",ref,file,anchor,sp);
      ol.writeCodeLink(ref,file,anchor,sp,tooltip);
      nextCodeLine();
    }
    else
    {
      //printf("writeCodeLink(%s,%s,%s,%s)\n",ref,file,anchor,sp);
      ol.writeCodeLink(ref,file,anchor,sp,tooltip);
      done=TRUE;
    }
  }
}

static void startFontClass(const char *s)
{
  // if font class is already set don't stop and start it.
  // strcmp does not like null pointers as input.
  if (!g_currentFontClass || !s || strcmp(g_currentFontClass,s))
  {
    endFontClass();
    g_code->startFontClass(s);
    g_currentFontClass=s;
  }
}

static void endFontClass()
{
  if (g_currentFontClass)
  {
    g_code->endFontClass();
    g_currentFontClass=0;
  }
}

static void codifyLines(char *text)
{
  //printf("codifyLines(%d,\"%s\")\n",g_yyLineNr,text);
  char *p=text,*sp=p;
  char c;
  bool done=FALSE;
  const char *  tmp_currentFontClass = g_currentFontClass;
  while (!done)
  {
    sp=p;
    while ((c=*p++) && c!='\n') { }
    if (c=='\n')
    {
      g_yyLineNr++;
      *(p-1)='\0';
      g_code->codify(sp);
      endCodeLine();
      if (g_yyLineNr<g_inputLines)
      {
        startCodeLine();
      }
      if (tmp_currentFontClass)
      {
        startFontClass(tmp_currentFontClass);
      }
    }
    else
    {
      g_code->codify(sp);
      done=TRUE;
    }
  }
}

static void codifyLines(const QCString &str)
{
  char *tmp= (char *)malloc(str.length()+1);
  qstrcpy(tmp, str);
  codifyLines(tmp);
  free(tmp);
}

static bool getLinkInScope(const QCString &c,  // scope
                           const QCString &m,  // member
			   const char *memberText, // exact text
			   CodeOutputInterface &ol,
			   const char *text
			  )
{
  MemberDef    *md;
  ClassDef     *cd;
  FileDef      *fd;
  NamespaceDef *nd;
  GroupDef     *gd;
  //printf("Trying `%s'::`%s'\n",c.data(),m.data());
  if (getDefs(c,m,"()",md,cd,fd,nd,gd,FALSE,g_sourceFileDef) && 
      md->isLinkable())
  {
    //Definition *d=0;
    //if (cd) d=cd; else if (nd) d=nd; else if (fd) d=fd; else d=gd;

    Definition *d = md->getOuterScope()==Doxygen::globalScope ?
	            md->getBodyDef() : md->getOuterScope();
    //printf("Found! d=%s\n",d?d->name().data():"<none>");
    if (md->getGroupDef()) d = md->getGroupDef();
    if (d && d->isLinkable())
    {
      g_theCallContext.setClass(stripClassName(md->typeString(),md->getOuterScope()));
      //printf("g_currentDefinition=%p g_currentMemberDef=%p\n",
      //        g_currentDefinition,g_currentMemberDef);

      if (g_currentDefinition && g_currentMemberDef &&
	  md!=g_currentMemberDef && g_collectXRefs)
      {
	addDocCrossReference(g_currentMemberDef,md);
      }
      //printf("d->getReference()=`%s' d->getOutputBase()=`%s' name=`%s' member name=`%s'\n",d->getReference().data(),d->getOutputFileBase().data(),d->name().data(),md->name().data());
     
      writeMultiLineCodeLink(ol,md, text ? text : memberText);
      addToSearchIndex(text ? text : memberText);
      return TRUE;
    } 
  }
  return FALSE;
}

static bool getLink(const char *className,
                    const char *memberName,
		    CodeOutputInterface &ol,
		    const char *text=0)
{
  QCString m=removeRedundantWhiteSpace(memberName);
  QCString c=className;
  if (!getLinkInScope(c,m,memberName,ol,text))
  {
    if (!g_curClassName.isEmpty())
    {
      if (!c.isEmpty()) c.prepend("::");
      c.prepend(g_curClassName);
      return getLinkInScope(c,m,memberName,ol,text);
    }
    return FALSE;
  }
  return TRUE;
}


/*
  For a given string in the source code,
  finds its class or global id and links to it.
*/
static void generateClassOrGlobalLink(CodeOutputInterface &ol,char *clName,
                                      bool typeOnly=FALSE)
{
  QCString className=clName;

  // Don't do anything for empty text
  if (className.isEmpty()) return;

  DBG_CTX((stderr,"generateClassOrGlobalLink(className=%s)\n",className.data()));

  ClassDef *cd=0,*lcd=0;  /** Class def that we may find */
  MemberDef *md=0;        /** Member def that we may find */
  //bool isLocal=FALSE;

  if ((lcd=g_theVarContext.findVariable(className))==0) // not a local variable
  {
    Definition *d = g_currentDefinition;
    QCString scope = substitute(className,".","::");

    cd = getResolvedClass(d,g_sourceFileDef,substitute(className,".","::"),&md);

    DBG_CTX((stderr,"d=%s g_sourceFileDef=%s\n",
        d?d->displayName().data():"<null>",
        g_currentDefinition?g_currentDefinition->displayName().data():"<null>"));
    DBG_CTX((stderr,"is found as a type %s\n",cd?cd->name().data():"<null>"));

    if (cd==0 && md==0) // also see if it is variable or enum or enum value
    {
      NamespaceDef *nd = getResolvedNamespace(scope);
      if (nd)
      {
        writeMultiLineCodeLink(ol,nd,clName);
        addToSearchIndex(className);
        return;
      }
      else if (getLink(g_classScope,clName,ol,clName))
      {
	return;
      }
    }
  }
  else
  {
    if (lcd!=PyVariableContext::dummyContext) 
    {
      g_theCallContext.setClass(lcd);
    }
    //isLocal=TRUE;
    DBG_CTX((stderr,"is a local variable cd=%p!\n",cd));
  }

  if (cd && cd->isLinkable()) // is it a linkable class
  {
    writeMultiLineCodeLink(ol,cd,clName);
    addToSearchIndex(className);
    if (md)
    {
      Definition *d = md->getOuterScope()==Doxygen::globalScope ?
                      md->getBodyDef() : md->getOuterScope();
      if (md->getGroupDef()) d = md->getGroupDef();
      if (d && d->isLinkable() && md->isLinkable() && 
          g_currentMemberDef && g_collectXRefs)
      {
        addDocCrossReference(g_currentMemberDef,md);
      }
    }
  }
  else // not a class, maybe a global member
  {
    int scopeEnd = className.findRev(".");
    if (scopeEnd!=-1 && !typeOnly) // name with explicit scope
    {
      QCString scope = substitute(className.left(scopeEnd),".","::");
      QCString locName = className.right(className.length()-scopeEnd-1);
      ClassDef *mcd = getClass(scope);
      DBG_CTX((stderr,"scope=%s locName=%s mcd=%p\n",scope.data(),locName.data(),mcd));
      if (mcd)
      {
	MemberDef *md = mcd->getMemberByName(locName);
	if (md)
	{
          g_theCallContext.setClass(stripClassName(md->typeString(),md->getOuterScope()));
          writeMultiLineCodeLink(ol,md,clName);
          addToSearchIndex(className);
	  Definition *d = md->getOuterScope()==Doxygen::globalScope ?
	                  md->getBodyDef() : md->getOuterScope();
	  if (md->getGroupDef()) d = md->getGroupDef();
	  if (d && d->isLinkable() && md->isLinkable() && 
              g_currentMemberDef && g_collectXRefs)
	  {
	    addDocCrossReference(g_currentMemberDef,md);
	  }
	  return;
	}
      }
      else // check namespace as well
      {
        NamespaceDef *mnd = getResolvedNamespace(scope);
        if (mnd)
        {
  	  MemberDef *md=mnd->getMemberByName(locName);
	  if (md)
          {
	    //printf("name=%s scope=%s\n",locName.data(),scope.data());
	    g_theCallContext.setClass(stripClassName(md->typeString(),md->getOuterScope()));
            writeMultiLineCodeLink(ol,md,clName);
            addToSearchIndex(className);
	    Definition *d = md->getOuterScope()==Doxygen::globalScope ?
	                    md->getBodyDef() : md->getOuterScope();
	    if (md->getGroupDef()) d = md->getGroupDef();
	    if (d && d->isLinkable() && md->isLinkable() && 
                g_currentMemberDef && g_collectXRefs)
	    {
	      addDocCrossReference(g_currentMemberDef,md);
	    }
	    return;
          }
        }
      }
    }
    
    // nothing found, just write out the word
    codifyLines(clName);
    addToSearchIndex(clName);
  }
}

/*
   As of June 1, this function seems to work
   for file members, but scopes are not
   being correctly tracked for classes
   so it doesn't work for classes yet.

*/
static void generateFunctionLink(CodeOutputInterface &ol,char *funcName)
{
  //CodeClassDef *ccd=0;
  ClassDef *ccd=0;
  QCString locScope=g_classScope.copy();
  QCString locFunc=removeRedundantWhiteSpace(funcName);
  DBG_CTX((stdout,"*** locScope=%s locFunc=%s\n",locScope.data(),locFunc.data()));
  int i=locFunc.findRev("::");
  if (i>0)
  {
    locScope=locFunc.left(i);
    locFunc=locFunc.right(locFunc.length()-i-2).stripWhiteSpace();
  }
  //printf("generateFunctionLink(%s) classScope=`%s'\n",locFunc.data(),locScope.data());
  if (!locScope.isEmpty() && (ccd=g_codeClassSDict[locScope]))
  {
    //printf("using classScope %s\n",g_classScope.data());
    if (ccd->baseClasses())
    {
      BaseClassListIterator bcli(*ccd->baseClasses());
      for ( ; bcli.current() ; ++bcli)
      {
	if (getLink(bcli.current()->classDef->name(),locFunc,ol,funcName)) 
	{
	  return;
	}
      }
    }
  }
  if (!getLink(locScope,locFunc,ol,funcName))
  {
    generateClassOrGlobalLink(ol,funcName);
  }
  return;
}

static bool findMemberLink(CodeOutputInterface &ol,Definition *sym,const char *symName)
{
  //printf("sym %s outerScope=%s equal=%d\n",
  //    sym->name().data(),sym->getOuterScope()->name().data(),
  //    sym->getOuterScope()==g_currentDefinition);

  if (sym->getOuterScope() &&
      sym->getOuterScope()->definitionType()==Definition::TypeClass &&
      g_currentDefinition->definitionType()==Definition::TypeClass)
  {
    ClassDef *cd = (ClassDef*)sym->getOuterScope();
    ClassDef *thisCd = (ClassDef *)g_currentDefinition;
    if (sym->definitionType()==Definition::TypeMember)
    {
      if (g_currentMemberDef && g_collectXRefs)
      {
	addDocCrossReference(g_currentMemberDef,(MemberDef*)sym);
      }
    }
    DBG_CTX((stderr,"cd=%s thisCd=%s\n",cd?cd->name().data():"<none>",thisCd?thisCd->name().data():"<none>"));

    // TODO: find the nearest base class in case cd is a base class of
    // thisCd 
    if (cd==thisCd || (thisCd && thisCd->isBaseClass(cd,TRUE)))
    {
      writeMultiLineCodeLink(ol,sym,symName);
      return TRUE;
    }
  }
  return FALSE;
}

static void findMemberLink(CodeOutputInterface &ol,char *symName)
{
  //printf("Member reference: %s scope=%s member=%s\n",
  //    pycodeYYtext,
  //    g_currentDefinition?g_currentDefinition->name().data():"<none>",
  //    g_currentMemberDef?g_currentMemberDef->name().data():"<none>"
  //    );
  if (g_currentDefinition)
  {
    DefinitionIntf *di = Doxygen::symbolMap->find(symName);
    if (di)
    {
      if (di->definitionType()==DefinitionIntf::TypeSymbolList) // multiple symbols
      {
	DefinitionListIterator dli(*(DefinitionList*)di);
	Definition *sym;
	for (dli.toFirst();(sym=dli.current());++dli)
	{
	  if (findMemberLink(ol,sym,symName)) return;
	}
      }
      else // single symbol
      {
	if (findMemberLink(ol,(Definition*)di,symName)) return;
      }
    }
  }
  //printf("sym %s not found\n",&pycodeYYtext[5]);
  codify(symName);
}

#undef YY_INPUT
#define YY_INPUT(buf,result,max_size) result=yyread(buf,max_size);

static int yyread(char *buf,int max_size)
{
  int c=0;
  while( c < max_size && g_inputString[g_inputPosition] )
  {
    *buf = g_inputString[g_inputPosition++] ;
    c++; buf++;
  }
  return c;
}
















#line 2042 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pycode.cpp"

#define INITIAL 0
#define Body 1
#define FunctionDec 2
#define FunctionParams 3
#define ClassDec 4
#define ClassInheritance 5
#define Suite 6
#define SuiteCaptureIndent 7
#define SuiteStart 8
#define SuiteMaintain 9
#define SuiteContinuing 10
#define LongString 11
#define SingleQuoteString 12
#define DoubleQuoteString 13
#define TripleString 14
#define DocBlock 15

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int pycodeYYlex_destroy (void );

int pycodeYYget_debug (void );

void pycodeYYset_debug (int debug_flag  );

YY_EXTRA_TYPE pycodeYYget_extra (void );

void pycodeYYset_extra (YY_EXTRA_TYPE user_defined  );

FILE *pycodeYYget_in (void );

void pycodeYYset_in  (FILE * in_str  );

FILE *pycodeYYget_out (void );

void pycodeYYset_out  (FILE * out_str  );

yy_size_t pycodeYYget_leng (void );

char *pycodeYYget_text (void );

int pycodeYYget_lineno (void );

void pycodeYYset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int pycodeYYwrap (void );
#else
extern int pycodeYYwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( pycodeYYtext, pycodeYYleng, 1, pycodeYYout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( pycodeYYin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( pycodeYYin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, pycodeYYin))==0 && ferror(pycodeYYin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(pycodeYYin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int pycodeYYlex (void);

#define YY_DECL int pycodeYYlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after pycodeYYtext and pycodeYYleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)pycodeYYalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in pycodeYYlex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! pycodeYYin )
			pycodeYYin = stdin;

		if ( ! pycodeYYout )
			pycodeYYout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			pycodeYYensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				pycodeYY_create_buffer(pycodeYYin,YY_BUF_SIZE );
		}

		pycodeYY_load_buffer_state( );
		}

	{
#line 989 "pycode.l"


#line 2285 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pycode.cpp"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of pycodeYYtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 540 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 539 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */

case 1:
YY_RULE_SETUP
#line 992 "pycode.l"
{
				        startFontClass("keyword");
					codify(pycodeYYtext);
					endFontClass();
					BEGIN( FunctionDec );
		                    }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 999 "pycode.l"
{
				        startFontClass("keyword");
					codify(pycodeYYtext);
					endFontClass();
					BEGIN( ClassDec );
		                    }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 1005 "pycode.l"
{
				        startFontClass("keywordtype");
					codify(pycodeYYtext);
					endFontClass();
				    }
	YY_BREAK
case 4:
*yy_cp = (yy_hold_char); /* undo effects of setting up pycodeYYtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up pycodeYYtext again */
YY_RULE_SETUP
#line 1010 "pycode.l"
{
				        codify("self.");
				        findMemberLink(*g_code,&pycodeYYtext[5]);
	                            }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 1014 "pycode.l"
{
				        codify("self.");
				        findMemberLink(*g_code,&pycodeYYtext[5]);
	                            }
	YY_BREAK
case 6:
*yy_cp = (yy_hold_char); /* undo effects of setting up pycodeYYtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up pycodeYYtext again */
YY_RULE_SETUP
#line 1018 "pycode.l"
{
				        codify("cls.");
				        findMemberLink(*g_code,&pycodeYYtext[4]);
	                            }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 1022 "pycode.l"
{
				        codify("cls.");
				        findMemberLink(*g_code,&pycodeYYtext[4]);
	                            }
	YY_BREAK

case 8:
YY_RULE_SETUP
#line 1028 "pycode.l"
{

					generateClassOrGlobalLink(*g_code,pycodeYYtext);
					// codify(pycodeYYtext);
					g_curClassName = pycodeYYtext;
					g_curClassBases.clear();
					BEGIN( ClassInheritance );
		                    }
	YY_BREAK

case 9:
YY_RULE_SETUP
#line 1038 "pycode.l"
{
					codify(pycodeYYtext);
                                    }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 1042 "pycode.l"
{
                                        // The parser
					// is assuming
					// that ALL identifiers
					// in this state
					// are base classes;
					// it doesn't check to see
					// that the first parenthesis
					// has been seen.

					// This is bad - it should
					// probably be more strict
					// about what to accept.

                                        g_curClassBases.inSort(pycodeYYtext);
					generateClassOrGlobalLink(*g_code,pycodeYYtext);
					// codify(pycodeYYtext);
                                    }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 1061 "pycode.l"
{
				      codify(pycodeYYtext);

				      // Assume this will
				      // be a one-line suite;
				      // found counter-example
				      // in SuiteStart.

                                      // Push a class scope

                                      ClassDef *classDefToAdd = new ClassDef("<code>",1,1,g_curClassName,ClassDef::Class,0,0,FALSE);
                                      g_codeClassSDict.append(g_curClassName,classDefToAdd);
                                      char *s=g_curClassBases.first();
                                      while (s) 
				      {
                                        ClassDef *baseDefToAdd;
                                        baseDefToAdd=g_codeClassSDict[s];

					// Try to find class in global
					// scope
					if (baseDefToAdd==0) 
					{
					  baseDefToAdd=getResolvedClass(g_currentDefinition,g_sourceFileDef,s);
					}

					if (baseDefToAdd && baseDefToAdd!=classDefToAdd) 
					{
				          classDefToAdd->insertBaseClass(baseDefToAdd,s,Public,Normal);
					}

                                        s=g_curClassBases.next();
			              }

				      // Reset class-parsing variables.
				      g_curClassName.resize(0);
				      g_curClassBases.clear();
				      
				      g_noSuiteFound = TRUE;
				      BEGIN( SuiteStart );
                                    }
	YY_BREAK


case 12:
YY_RULE_SETUP
#line 1105 "pycode.l"
{
                                        generateFunctionLink(*g_code,pycodeYYtext);
                                    }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 1109 "pycode.l"
{
				        codify(pycodeYYtext);
					BEGIN( FunctionParams );
		                    }
	YY_BREAK


case 14:
YY_RULE_SETUP
#line 1116 "pycode.l"
{
                                         // Parses delimiters
				         codify(pycodeYYtext);
                                    }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 1121 "pycode.l"
{
				         codify(pycodeYYtext);
                                    }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 1125 "pycode.l"
{
                                         codify(pycodeYYtext);
                                    }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 1129 "pycode.l"
{
				      codify(pycodeYYtext);

				      // Assume this will
				      // be a one-line suite;
				      // found counter-example
				      // in SuiteStart.
				      g_noSuiteFound = TRUE;
				      BEGIN( SuiteStart );
                                    }
	YY_BREAK


case 18:
YY_RULE_SETUP
#line 1143 "pycode.l"
{
                                 // Position-sensitive rules!
                                 // Must come AFTER keyword-triggered rules
                                 // Must come BEFORE identifier NONEMPTY-like rules
                                 //   to syntax highlight.

  		                 startFontClass("keyword");
  		                 codify(pycodeYYtext);
		                 endFontClass();
                               }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 1154 "pycode.l"
{
  		                 startFontClass("keywordflow");
  		                 codify(pycodeYYtext);
		                 endFontClass();
                               }
	YY_BREAK
case 20:
*yy_cp = (yy_hold_char); /* undo effects of setting up pycodeYYtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up pycodeYYtext again */
YY_RULE_SETUP
#line 1159 "pycode.l"
{
				 generateClassOrGlobalLink(*g_code,pycodeYYtext);
      			       }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 1162 "pycode.l"
{
				 generateClassOrGlobalLink(*g_code,pycodeYYtext,TRUE);
			       }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 1165 "pycode.l"
{ codify(pycodeYYtext); }
	YY_BREAK


case 23:
YY_RULE_SETUP
#line 1173 "pycode.l"
{
                                         codify(pycodeYYtext);
                                       }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 1176 "pycode.l"
{
                                          startFontClass("keyword");
					  codifyLines(pycodeYYtext);
		                          endFontClass();
					  BEGIN(Body);
      				       }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 1182 "pycode.l"
{
                                          startFontClass("keyword");
					  codifyLines(pycodeYYtext);
		                          endFontClass();

					  // No indentation necessary
					  g_noSuiteFound = FALSE;
                                       }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 1191 "pycode.l"
{
                                          startFontClass("keywordflow");
					  codifyLines(pycodeYYtext);
		                          endFontClass();

					  // No indentation necessary
					  g_noSuiteFound = FALSE;
                                       }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 1199 "pycode.l"
{
                                         codify(pycodeYYtext);
				       } 
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 1204 "pycode.l"
{
  				         if (YY_START==SingleQuoteString || 
				             YY_START==DoubleQuoteString || 
				             YY_START==TripleString
				            )
				         {
				           REJECT;
				         }
                                         yy_push_state(YY_START);
				         BEGIN(DocBlock);
				         g_docBlock=pycodeYYtext;
                                       }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 1217 "pycode.l"
{
					  codifyLines(pycodeYYtext);
					  if ( g_noSuiteFound ) 
					  {
                                            // printf("New suite to capture! [%d]\n", g_yyLineNr);
					    BEGIN ( SuiteCaptureIndent );
					  }
                                       }
	YY_BREAK


case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 1228 "pycode.l"
{
                                 // Blankline - ignore, keep looking for indentation.
				 codifyLines(pycodeYYtext);
                               }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 1233 "pycode.l"
{
                                 // This state lasts momentarily,
                                 // to check the indentation
                                 // level that is about to be
                                 // used.
				 codifyLines(pycodeYYtext);
				 g_indents.push(pycodeYYleng);
                                 // printf("Captured indent of %d [line %d]\n", pycodeYYleng, g_yyLineNr);
				 BEGIN( Suite );
                               }
	YY_BREAK


case 32:
YY_RULE_SETUP
#line 1247 "pycode.l"
{
                                 // This implements poor
				 // indendation-tracking;
                                 // should be improved.
				 // (translate tabs to space, etc)
  		                 codifyLines(pycodeYYtext);
                                 adjustScopesAndSuites((int)pycodeYYleng);
                               }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 1256 "pycode.l"
{
                                 // If this ever succeeds,
				 // it means that this is
				 // a blank line, and
				 // can be ignored.
  		                 codifyLines(pycodeYYtext);
                               }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 1264 "pycode.l"
{
                                 // Default rule; matches
				 // the empty string, assuming
				 // real text starts here.
				 // Just go straight to Body.
                                 adjustScopesAndSuites(0);
                               }
	YY_BREAK

case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 1274 "pycode.l"
{
                                 codifyLines(pycodeYYtext);
			         BEGIN( SuiteMaintain );
		               }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 1278 "pycode.l"
{
  			         codify(pycodeYYtext);
                               }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 1281 "pycode.l"
{
  		                 codifyLines(pycodeYYtext);
                               }
	YY_BREAK
// Single quoted string like 'That\'s a """nice""" string!'
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
#line 1286 "pycode.l"
{ // line continuation
  		                 codifyLines(pycodeYYtext);
                               }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 1289 "pycode.l"
{ // espaced char
  		                 codify(pycodeYYtext);
                               }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 1292 "pycode.l"
{ // tripple double quotes
  		                 codify(pycodeYYtext);
      			       }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 1295 "pycode.l"
{ // end of the string
  		                 codify(pycodeYYtext);
				 endFontClass();
      		                 BEGIN(g_stringContext);
                               }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 1300 "pycode.l"
{ // normal chars
  		                 codify(pycodeYYtext);
                               }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 1303 "pycode.l"
{ // normal char
  		                 codify(pycodeYYtext);
                               }
	YY_BREAK

// Double quoted string like "That's \"a '''nice'''\" string!"
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 1309 "pycode.l"
{ // line continuation
  		                 codifyLines(pycodeYYtext);
                               }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 1312 "pycode.l"
{ // espaced char
  		                 codify(pycodeYYtext);
                               }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 1315 "pycode.l"
{ // tripple single quotes
  		                 codify(pycodeYYtext);
      			       }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 1318 "pycode.l"
{ // end of the string
  		                 codify(pycodeYYtext);
				 endFontClass();
      		                 BEGIN(g_stringContext);
                               }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 1323 "pycode.l"
{ // normal chars
  		                 codify(pycodeYYtext);
                               }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 1326 "pycode.l"
{ // normal char
  		                 codify(pycodeYYtext);
                               }
	YY_BREAK


case 50:
#line 1333 "pycode.l"
case 51:
YY_RULE_SETUP
#line 1333 "pycode.l"
{
  		          codify(pycodeYYtext);
			  if (g_doubleQuote==(pycodeYYtext[0]=='"')) 
			  {
			    endFontClass();
			    BEGIN(g_stringContext);
			  }
		       }
	YY_BREAK
case 52:
/* rule 52 can match eol */
YY_RULE_SETUP
#line 1341 "pycode.l"
{
			 codifyLines(pycodeYYtext);
		       }
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 1344 "pycode.l"
{
			 codifyLines(pycodeYYtext);
                       }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 1347 "pycode.l"
{
                         codify(pycodeYYtext);
                       }
	YY_BREAK

/*
<*>({NONEMPTY}|{EXPCHAR}|{BB})           { // This should go one character at a time.
  		                 codify(pycodeYYtext);
				 // printf("[pycode] '%s' [ state %d ]  [line %d] no match\n",
				 //       pycodeYYtext, YY_START, g_yyLineNr);

				 //endFontClass();
				 BEGIN(Body);					
                               }
   */
case 55:
#line 1364 "pycode.l"
case 56:
YY_RULE_SETUP
#line 1364 "pycode.l"
{
  				 startFontClass("stringliteral");
				 g_stringContext=YY_START;
				 g_doubleQuote=pycodeYYtext[pycodeYYleng-1]=='"';
  		                 codify(pycodeYYtext);
				 BEGIN(TripleString);
                               }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 1371 "pycode.l"
{ // single quoted string
  				 startFontClass("stringliteral");
				 g_stringContext=YY_START;
  		                 codify(pycodeYYtext);
				 BEGIN(SingleQuoteString);
  			       }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 1377 "pycode.l"
{ // double quoted string
  				 startFontClass("stringliteral");
				 g_stringContext=YY_START;
  		                 codify(pycodeYYtext);
				 BEGIN(DoubleQuoteString);
                               }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 1383 "pycode.l"
{ // contents of current comment line
                                 g_docBlock+=pycodeYYtext;
  			       }
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 1386 "pycode.l"
{ // comment block (next line is also comment line)
				 g_docBlock+=pycodeYYtext; 
   			       }
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 1389 "pycode.l"
{ // comment block ends at the end of this line
                                 // remove special comment (default config)
				 if (Config_getBool("STRIP_CODE_COMMENTS"))
				 {
				    g_yyLineNr+=((QCString)g_docBlock).contains('\n');
				    g_endComment=TRUE;
				  }
				  else // do not remove comment
				  {
				    startFontClass("comment");
				    codifyLines(g_docBlock);
				    endFontClass();
				  }
				  unput(*pycodeYYtext);
				  yy_pop_state();
			       }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 1405 "pycode.l"
{
  				 if (YY_START==SingleQuoteString || 
				     YY_START==DoubleQuoteString || 
				     YY_START==TripleString
				    )
				 {
				   REJECT;
				 }
                                 yy_push_state(YY_START);
				 BEGIN(DocBlock);
				 g_docBlock=pycodeYYtext;
                               }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 1417 "pycode.l"
{ // normal comment
  				 if (YY_START==SingleQuoteString || 
				     YY_START==DoubleQuoteString || 
				     YY_START==TripleString
				    )
				 {
				   REJECT;
				 }
                                 startFontClass("comment");
                                 codifyLines(pycodeYYtext);
                                 endFontClass();
                               }
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 1429 "pycode.l"
{
				  if (g_endComment)
				  {
				    g_endComment=FALSE;
				  }
				  else
				  {
				    codifyLines(pycodeYYtext);
				  }
				 //printf("[pycode] %d NEWLINE [line %d] no match\n",
				 //       YY_START, g_yyLineNr);

				 //endFontClass();
				 BEGIN(Body);
                               }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 1445 "pycode.l"
{
  		                 codify(pycodeYYtext);
				 BEGIN(Body);					
  			       }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 1449 "pycode.l"
{
  		                 codify(pycodeYYtext);
				 // printf("[pycode] '%s' [ state %d ]  [line %d] no match\n",
				 //        pycodeYYtext, YY_START, g_yyLineNr);

				 //endFontClass();
				 BEGIN(Body);					
                               }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(Body):
case YY_STATE_EOF(FunctionDec):
case YY_STATE_EOF(FunctionParams):
case YY_STATE_EOF(ClassDec):
case YY_STATE_EOF(ClassInheritance):
case YY_STATE_EOF(Suite):
case YY_STATE_EOF(SuiteCaptureIndent):
case YY_STATE_EOF(SuiteStart):
case YY_STATE_EOF(SuiteMaintain):
case YY_STATE_EOF(SuiteContinuing):
case YY_STATE_EOF(LongString):
case YY_STATE_EOF(SingleQuoteString):
case YY_STATE_EOF(DoubleQuoteString):
case YY_STATE_EOF(TripleString):
case YY_STATE_EOF(DocBlock):
#line 1458 "pycode.l"
{
                                 if (YY_START == DocBlock) {
                                   if (!Config_getBool("STRIP_CODE_COMMENTS"))
                                   {
                                     startFontClass("comment");
                                     codifyLines(g_docBlock);
                                     endFontClass();
                                   }
                                 }
                                 yyterminate();
                               }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 1469 "pycode.l"
ECHO;
	YY_BREAK
#line 3109 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pycode.cpp"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed pycodeYYin at a new source and called
			 * pycodeYYlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = pycodeYYin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( pycodeYYwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * pycodeYYtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of pycodeYYlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			pycodeYYrestart(pycodeYYin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) pycodeYYrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 540 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 540 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 539);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up pycodeYYtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					pycodeYYrestart(pycodeYYin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( pycodeYYwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve pycodeYYtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void pycodeYYrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        pycodeYYensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            pycodeYY_create_buffer(pycodeYYin,YY_BUF_SIZE );
	}

	pycodeYY_init_buffer(YY_CURRENT_BUFFER,input_file );
	pycodeYY_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void pycodeYY_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		pycodeYYpop_buffer_state();
	 *		pycodeYYpush_buffer_state(new_buffer);
     */
	pycodeYYensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	pycodeYY_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (pycodeYYwrap()) processing, but the only time this flag
	 * is looked at is after pycodeYYwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void pycodeYY_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	pycodeYYin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE pycodeYY_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) pycodeYYalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pycodeYY_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) pycodeYYalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in pycodeYY_create_buffer()" );

	b->yy_is_our_buffer = 1;

	pycodeYY_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with pycodeYY_create_buffer()
 * 
 */
    void pycodeYY_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		pycodeYYfree((void *) b->yy_ch_buf  );

	pycodeYYfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a pycodeYYrestart() or at EOF.
 */
    static void pycodeYY_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	pycodeYY_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then pycodeYY_init_buffer was _probably_
     * called from pycodeYYrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void pycodeYY_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		pycodeYY_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void pycodeYYpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	pycodeYYensure_buffer_stack();

	/* This block is copied from pycodeYY_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from pycodeYY_switch_to_buffer. */
	pycodeYY_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void pycodeYYpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	pycodeYY_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		pycodeYY_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void pycodeYYensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)pycodeYYalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pycodeYYensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)pycodeYYrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pycodeYYensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE pycodeYY_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) pycodeYYalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pycodeYY_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	pycodeYY_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to pycodeYYlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       pycodeYY_scan_bytes() instead.
 */
YY_BUFFER_STATE pycodeYY_scan_string (yyconst char * yystr )
{
    
	return pycodeYY_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to pycodeYYlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE pycodeYY_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) pycodeYYalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in pycodeYY_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = pycodeYY_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in pycodeYY_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) pycodeYYalloc(new_size  );

		else
			(yy_start_stack) = (int *) pycodeYYrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pycodeYYtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		pycodeYYtext[pycodeYYleng] = (yy_hold_char); \
		(yy_c_buf_p) = pycodeYYtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		pycodeYYleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int pycodeYYget_lineno  (void)
{
        
    return pycodeYYlineno;
}

/** Get the input stream.
 * 
 */
FILE *pycodeYYget_in  (void)
{
        return pycodeYYin;
}

/** Get the output stream.
 * 
 */
FILE *pycodeYYget_out  (void)
{
        return pycodeYYout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t pycodeYYget_leng  (void)
{
        return pycodeYYleng;
}

/** Get the current token.
 * 
 */

char *pycodeYYget_text  (void)
{
        return pycodeYYtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void pycodeYYset_lineno (int  line_number )
{
    
    pycodeYYlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see pycodeYY_switch_to_buffer
 */
void pycodeYYset_in (FILE *  in_str )
{
        pycodeYYin = in_str ;
}

void pycodeYYset_out (FILE *  out_str )
{
        pycodeYYout = out_str ;
}

int pycodeYYget_debug  (void)
{
        return pycodeYY_flex_debug;
}

void pycodeYYset_debug (int  bdebug )
{
        pycodeYY_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from pycodeYYlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    pycodeYYin = stdin;
    pycodeYYout = stdout;
#else
    pycodeYYin = (FILE *) 0;
    pycodeYYout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * pycodeYYlex_init()
     */
    return 0;
}

/* pycodeYYlex_destroy is for both reentrant and non-reentrant scanners. */
int pycodeYYlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		pycodeYY_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		pycodeYYpop_buffer_state();
	}

	/* Destroy the stack itself. */
	pycodeYYfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        pycodeYYfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    pycodeYYfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * pycodeYYlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *pycodeYYalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *pycodeYYrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void pycodeYYfree (void * ptr )
{
	free( (char *) ptr );	/* see pycodeYYrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 1469 "pycode.l"



/*@ ----------------------------------------------------------------------------
 */

void resetPythonCodeParserState() 
{
  g_currentDefinition = 0;
  g_currentMemberDef = 0;
  g_doubleStringIsDoc = FALSE;
  g_paramParens = 0;
  g_indents.clear();
  BEGIN( Body );
}

/*!
  Examines current stack of white-space indentations;
  re-syncs the parser with the correct scope.
*/
static void adjustScopesAndSuites(unsigned indentLength) 
{
  // States to pop
  if (!g_indents.isEmpty() && indentLength < g_indents.top()) 
  {
    while (!g_indents.isEmpty() && indentLength < g_indents.top()) 
    {
      // printf("Exited scope indent of [%d]\n", g_indents.top());
      g_indents.pop(); // Pop the old suite's indentation

      g_currentMemberDef=0;
      if (g_currentDefinition) 
	g_currentDefinition=g_currentDefinition->getOuterScope();
    }
  }

  // Are there any remaining indentation levels for suites?
  if (!g_indents.isEmpty()) 
  {
    BEGIN( Suite );
  }
  else 
  {
    BEGIN( Body );
  }
}

void parsePythonCode(CodeOutputInterface &od,const char * /*className*/,
                 const QCString &s,bool exBlock, const char *exName,
		 FileDef *fd,int startLine,int endLine,bool /*inlineFragment*/,
		 MemberDef *,bool,Definition *searchCtx,bool collectXRefs) 
{

  //printf("***parseCode()\n");
  
  //--------------------------------------
  if (s.isEmpty()) return;
  printlex(pycodeYY_flex_debug, TRUE, __FILE__, fd ? fd->fileName().data(): NULL);
  TooltipManager::instance()->clearTooltips();
  g_code = &od;
  g_inputString   = s;
  g_inputPosition = 0;
  g_currentFontClass = 0;
  g_needsTermination = FALSE;
  g_searchCtx=searchCtx;
  g_collectXRefs=collectXRefs;
  if (endLine!=-1)
    g_inputLines  = endLine+1;
  else
    g_inputLines  = countLines();
  
  if (startLine!=-1)
    g_yyLineNr    = startLine;
  else
    g_yyLineNr    = 1;
  
  g_exampleBlock  = exBlock; 
  g_exampleName   = exName;
  g_sourceFileDef = fd;

  bool cleanupSourceDef = FALSE;
  if (fd==0)
  {
    // create a dummy filedef for the example
    g_sourceFileDef = new FileDef("",(exName?exName:"generated"));
    cleanupSourceDef = TRUE;
  }
  if (g_sourceFileDef) 
  {
    setCurrentDoc("l00001");
  }

  // Starts line 1 on the output  
  startCodeLine();

  pycodeYYrestart( pycodeYYin );

  pycodeYYlex();

  if (!g_indents.isEmpty()) 
  {
    // printf("Exited pysourceparser in inconsistent state!\n");
  }

  if (g_needsTermination)
  {
    endCodeLine();
  }
  if (fd)
  {
    TooltipManager::instance()->writeTooltips(*g_code);
  }
  if (cleanupSourceDef)
  {
    // delete the temporary file definition used for this example
    delete g_sourceFileDef;
    g_sourceFileDef=0;
  }
  printlex(pycodeYY_flex_debug, FALSE, __FILE__, fd ? fd->fileName().data(): NULL);
  return;
}


#if !defined(YY_FLEX_SUBMINOR_VERSION) 
extern "C" { // some bogus code to keep the compiler happy
  void pycodeYYdummy() { yy_flex_realloc(0,0); } 
}
#elif YY_FLEX_MAJOR_VERSION<=2 && YY_FLEX_MINOR_VERSION<=5 && YY_FLEX_SUBMINOR_VERSION<33
#error "You seem to be using a version of flex newer than 2.5.4. These are currently incompatible with 2.5.4, and do NOT work with doxygen! Please use version 2.5.4 or expect things to be parsed wrongly! A bug report has been submitted (#732132)."
#endif


